@@ -300,7 +300,7 @@ Rcpp::List maaipm_fixed_cpp(arma::vec p, arma::vec s, arma::vec x,const arma::ve
     xx.subvec(M,nr-2)= xx.subvec(M,nr-2)-(alpha*xx(nr-1)/cc);
     xx.subvec(0,M-1)=xx.subvec(0,M-1)/B1diag;
     xx(nr-1)/=cc;
-    if ((rel_gap>=(10^-4))&& (largesupp)){
+    if ((rel_gap>=(1e-4))&& (largesupp)){
       xx.subvec(M,nr-2)=DLRM_intern(B1,B2,B3inv,Y,sizescsum, xx.subvec(M,nr-2),N,m,U);
     }
     else{   
@@ -343,7 +343,7 @@ Rcpp::List maaipm_fixed_cpp(arma::vec p, arma::vec s, arma::vec x,const arma::ve
     xx.subvec(M,nr-2)= xx.subvec(M,nr-2)-(alpha*xx(nr-1)/cc);
     xx.subvec(0,M-1)=xx.subvec(0,M-1)/B1diag;
     xx(nr-1)/=cc;
-    if ((rel_gap>=(10^-4))&& (largesupp)){
+    if ((rel_gap>=(1e-4))&& (largesupp)){
       xx.subvec(M,nr-2)=DLRM_intern(B1,B2,B3inv,Y,sizescsum, xx.subvec(M,nr-2),N,m,U);
     }
     else{   
@@ -531,7 +531,7 @@ Rcpp::List maaipm_free_cpp(arma::vec p, arma::vec s, arma::vec x,const arma::vec
       xx.subvec(M,nr-2)= xx.subvec(M,nr-2)-(alpha*xx(nr-1)/cc);
       xx.subvec(0,M-1)=xx.subvec(0,M-1)/B1diag;
       xx(nr-1)/=cc;
-      if ((rel_gap>=(10^-4))&& (largesupp)){
+      if ((rel_gap>=(1e-4))&& (largesupp)){
         xx.subvec(M,nr-2)=DLRM_intern(B1,B2,B3inv,Y,sizescsum, xx.subvec(M,nr-2),N,m,U);
       }
       else{   
@@ -574,7 +574,7 @@ Rcpp::List maaipm_free_cpp(arma::vec p, arma::vec s, arma::vec x,const arma::vec
       xx.subvec(M,nr-2)= xx.subvec(M,nr-2)-(alpha*xx(nr-1)/cc);
       xx.subvec(0,M-1)=xx.subvec(0,M-1)/B1diag;
       xx(nr-1)/=cc;
-      if ((rel_gap>=(10^-4))&& (largesupp)){
+      if ((rel_gap>=(1e-4))&& (largesupp)){
         xx.subvec(M,nr-2)=DLRM_intern(B1,B2,B3inv,Y,sizescsum, xx.subvec(M,nr-2),N,m,U);
       }
       else{   
